@@ -6,8 +6,9 @@ import (
 	"bytes"
 	"testing"
 
-	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
+	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestPrint(t *testing.T) {
@@ -16,12 +17,12 @@ func TestPrint(t *testing.T) {
 	interactive.IsInteractive = true
 
 	n, err := interactive.Print("Test", 42)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 6, n)
 
 	interactive.IsInteractive = false
 	n, err = interactive.Print("Test", 42)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 0, n)
 
 	assert.Equal(t, "Test42", buffer.String())
@@ -33,12 +34,12 @@ func TestPrintln(t *testing.T) {
 	interactive.IsInteractive = true
 
 	n, err := interactive.Println("Test", 42)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 8, n)
 
 	interactive.IsInteractive = false
 	n, err = interactive.Println("Test", 42)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 0, n)
 
 	assert.Equal(t, "Test 42\n", buffer.String())
@@ -50,12 +51,12 @@ func TestPrintf(t *testing.T) {
 	interactive.IsInteractive = true
 
 	n, err := interactive.Printf("%s %d", "Test", 42)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 7, n)
 
 	interactive.IsInteractive = false
 	n, err = interactive.Printf("%s %d", "Test", 42)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, 0, n)
 
 	assert.Equal(t, "Test 42", buffer.String())
