@@ -3,7 +3,7 @@ package baremetal_test
 import (
 	"testing"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/baremetal/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
 )
