@@ -2,7 +2,7 @@
 
 package container
 
-import "github.com/scaleway/scaleway-cli/v2/internal/core"
+import "github.com/scaleway/scaleway-cli/v2/core"
 
 func containerDeployCommand() *core.Command {
 	return nil
