@@ -3,10 +3,10 @@ package iam_test
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/account/v3"
 	iam "github.com/scaleway/scaleway-cli/v2/internal/namespaces/iam/v1alpha1"
+	"github.com/stretchr/testify/assert"
 )
 
 func Test_getPolicyWithRules(t *testing.T) {
