@@ -11,7 +11,7 @@ func Test_GetPlacementGroup(t *testing.T) {
 	t.Run("simple", core.Test(&core.TestConfig{
 		BeforeFunc: core.BeforeFuncCombine(
 			core.ExecStoreBeforeCmd("PlacementGroup", "scw instance placement-group create"),
-			core.ExecStoreBeforeCmd("ServerA", "scw instance server create type=DEV1-S image=ubuntu_jammy stopped=true placement-group-id={{ .PlacementGroup.PlacementGroup.ID }}"),
+			core.ExecStoreBeforeCmd("ServerA", "scw instance server create type=DEV1-S image=ubuntu_jammy ip=none stopped=true placement-group-id={{ .PlacementGroup.PlacementGroup.ID }}"),
 		),
 		Commands: instance.GetCommands(),
 		Cmd:      "scw instance placement-group get {{ .PlacementGroup.PlacementGroup.ID }}",
