@@ -15,6 +15,7 @@ import (
 	"github.com/fatih/color"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/core/human"
+	block "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/vpc/v2"
 	"github.com/scaleway/scaleway-sdk-go/logger"
@@ -49,6 +50,7 @@ func serverLocationMarshalerFunc(i interface{}, _ *human.MarshalOpt) (string, er
 	if err != nil {
 		return "", err
 	}
+
 	return string(zone), nil
 }
 
@@ -114,6 +116,7 @@ func serversMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error)
 			ImageID:           serverImageID,
 		})
 	}
+
 	return human.Marshal(humanServers, opt)
 }
 
@@ -129,12 +132,14 @@ func orderVolumes(v map[string]*instance.VolumeServer) []*instance.VolumeServer
 	for _, index := range indexes {
 		orderedVolumes = append(orderedVolumes, v[index])
 	}
+
 	return orderedVolumes
 }
 
 // serversMarshalerFunc marshals a BootscriptID.
 func bootscriptMarshalerFunc(i interface{}, _ *human.MarshalOpt) (string, error) {
 	bootscript := i.(instance.Bootscript)
+
 	return bootscript.Title, nil
 }
 
@@ -167,6 +172,7 @@ func serverListBuilder(c *core.Command) *core.Command {
 
 		return runner(ctx, request)
 	})
+
 	return c
 }
 
@@ -291,9 +297,17 @@ func serverUpdateBuilder(c *core.Command) *core.Command {
 			volumes := make(map[string]*instance.VolumeServerTemplate)
 			for i, volumeID := range *customRequest.VolumeIDs {
 				index := strconv.Itoa(i)
-				volumes[index] = &instance.VolumeServerTemplate{
-					ID:   scw.StringPtr(volumeID),
-					Name: scw.StringPtr(getServerResponse.Server.Name + "-" + index),
+
+				if volumeIsFromSBS(block.NewAPI(client), customRequest.Zone, volumeID) {
+					volumes[index] = &instance.VolumeServerTemplate{
+						ID:         scw.StringPtr(volumeID),
+						VolumeType: instance.VolumeVolumeTypeSbsVolume,
+					}
+				} else {
+					volumes[index] = &instance.VolumeServerTemplate{
+						ID:   scw.StringPtr(volumeID),
+						Name: scw.StringPtr(getServerResponse.Server.Name + "-" + index),
+					}
 				}
 			}
 			customRequest.Volumes = &volumes
@@ -323,6 +337,15 @@ func serverUpdateBuilder(c *core.Command) *core.Command {
 	return c
 }
 
+func volumeIsFromSBS(api *block.API, zone scw.Zone, volumeID string) bool {
+	_, err := api.GetVolume(&block.GetVolumeRequest{
+		Zone:     zone,
+		VolumeID: volumeID,
+	})
+
+	return err == nil
+}
+
 func serverGetBuilder(c *core.Command) *core.Command {
 	// This method is here as a proof of concept before we find the correct way to implement it at larger scale
 	c.ArgSpecs.GetPositionalArg().AutoCompleteFunc = func(ctx context.Context, prefix string, request any) core.AutocompleteSuggestions {
@@ -341,6 +364,7 @@ func serverGetBuilder(c *core.Command) *core.Command {
 				suggestion = append(suggestion, s.ID)
 			}
 		}
+
 		return suggestion
 	}
 
@@ -455,6 +479,7 @@ func serverAttachVolumeCommand() *core.Command {
 
 			client := core.ExtractClient(ctx)
 			api := instance.NewAPI(client)
+
 			return api.AttachVolume(request)
 		},
 		Examples: []*core.Example{
@@ -486,6 +511,7 @@ func serverDetachVolumeCommand() *core.Command {
 
 			client := core.ExtractClient(ctx)
 			api := instance.NewAPI(client)
+
 			return api.DetachVolume(request)
 		},
 		Examples: []*core.Example{
@@ -560,6 +586,7 @@ func serverAttachIPCommand() *core.Command {
 			if err != nil {
 				return nil, err
 			}
+
 			return api.GetServer(&instance.GetServerRequest{ServerID: args.ServerID})
 		},
 		Examples: []*core.Example{
@@ -621,10 +648,13 @@ func serverDetachIPCommand() *core.Command {
 					if err != nil {
 						return nil, err
 					}
+
 					return api.GetServer(&instance.GetServerRequest{ServerID: args.ServerID})
 				}
+
 				return nil, errors.New("no public ip found")
 			}
+
 			return nil, errors.New("no server found")
 		},
 		Examples: []*core.Example{
