@@ -99,6 +99,7 @@ func clusterAvailableVersionsListBuilder(c *core.Command) *core.Command {
 		}
 
 		listClusterAvailableVersionsResponse := originalRes.(*k8s.ListClusterAvailableVersionsResponse)
+
 		return listClusterAvailableVersionsResponse.Versions, nil
 	})
 
@@ -164,10 +165,14 @@ func clusterCreateBuilder(c *core.Command) *core.Command {
 
 		if request.Type == "" || strings.HasPrefix(request.Type, "kapsule") {
 			if request.PrivateNetworkID == nil {
-				pn, err = vpcAPI.CreatePrivateNetwork(&vpc.CreatePrivateNetworkRequest{
+				createPNReq := &vpc.CreatePrivateNetworkRequest{
 					Region: request.Region,
 					Tags:   []string{"created-along-with-k8s-cluster", "created-by-cli"},
-				}, scw.WithContext(ctx))
+				}
+				if request.ProjectID != nil {
+					createPNReq.ProjectID = *request.ProjectID
+				}
+				pn, err = vpcAPI.CreatePrivateNetwork(createPNReq, scw.WithContext(ctx))
 				if err != nil {
 					return nil, err
 				}
@@ -196,6 +201,7 @@ func clusterCreateBuilder(c *core.Command) *core.Command {
 					return nil, errors.Join(err, errPN)
 				}
 			}
+
 			return nil, err
 		}
 
@@ -316,16 +322,19 @@ func clusterGetBuilder(c *core.Command) *core.Command {
 
 func clusterDeleteBuilder(c *core.Command) *core.Command {
 	c.WaitFunc = waitForClusterFunc(clusterActionDelete)
+
 	return c
 }
 
 func clusterUpgradeBuilder(c *core.Command) *core.Command {
 	c.WaitFunc = waitForClusterFunc(clusterActionUpgrade)
+
 	return c
 }
 
 func clusterUpdateBuilder(c *core.Command) *core.Command {
 	c.WaitFunc = waitForClusterFunc(clusterActionUpdate)
+
 	return c
 }
 
@@ -363,6 +372,7 @@ func waitForClusterFunc(action int) core.WaitFunc {
 				}
 			}
 		}
+
 		return nil, err
 	}
 }
@@ -372,6 +382,7 @@ func k8sClusterWaitCommand() *core.Command {
 		k8s.WaitForClusterRequest
 		WaitForPools bool
 	}
+
 	return &core.Command{
 		Short:     `Wait for a cluster to reach a stable state`,
 		Long:      `Wait for server to reach a stable state. This is similar to using --wait flag on other action commands, but without requiring a new action on the server.`,
