@@ -3,11 +3,12 @@ package k8s_test
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
 	"github.com/ghodss/yaml"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1"
 	api "github.com/scaleway/scaleway-cli/v2/internal/namespaces/k8s/v1/types"
+	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func Test_GetKubeconfig(t *testing.T) {
@@ -23,7 +24,7 @@ func Test_GetKubeconfig(t *testing.T) {
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				config, err := yaml.Marshal(ctx.Meta["Kubeconfig"].(api.Config))
-				assert.Equal(t, err, nil)
+				require.NoError(t, err)
 				assert.Equal(t, ctx.Result.(string), string(config))
 			},
 			core.TestCheckExitCode(0),
