@@ -3,9 +3,9 @@ package rdb_test
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/rdb/v1"
+	"github.com/stretchr/testify/assert"
 )
 
 func Test_AddACL(t *testing.T) {
