@@ -11,7 +11,7 @@ import (
 func Test_ListUser(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        "scw rdb user list instance-id={{ .Instance.ID }}",
 		Check:      core.TestCheckGolden(),
 		AfterFunc:  deleteInstance(),
@@ -21,7 +21,7 @@ func Test_ListUser(t *testing.T) {
 func Test_CreateUser(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        fmt.Sprintf("scw rdb user create instance-id={{ $.Instance.Instance.ID }} name=%s password=%s", name, password),
 		Check:      core.TestCheckGolden(),
 		AfterFunc:  deleteInstance(),
@@ -29,7 +29,7 @@ func Test_CreateUser(t *testing.T) {
 
 	t.Run("With password generator", core.Test(&core.TestConfig{
 		Commands:   rdb.GetCommands(),
-		BeforeFunc: createInstance("PostgreSQL-12"),
+		BeforeFunc: core.BeforeFuncCombine(fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}")),
 		Cmd:        fmt.Sprintf("scw rdb user create instance-id={{ $.Instance.Instance.ID }} name=%s generate-password=true", name),
 		// do not check the golden as the password generated locally and on CI will necessarily be different
 		Check:     core.TestCheckExitCode(0),
@@ -41,7 +41,7 @@ func Test_UpdateUser(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands: rdb.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
-			createInstance("PostgreSQL-12"),
+			fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}"),
 			core.ExecBeforeCmd(fmt.Sprintf("scw rdb user create instance-id={{ $.Instance.Instance.ID }} name=%s password=%s", name, password)),
 		),
 		Cmd:       fmt.Sprintf("scw rdb user update instance-id={{ $.Instance.Instance.ID }} name=%s password=Newp1ssw0rd! is-admin=true", name),
@@ -52,7 +52,7 @@ func Test_UpdateUser(t *testing.T) {
 	t.Run("With password generator", core.Test(&core.TestConfig{
 		Commands: rdb.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
-			createInstance("PostgreSQL-12"),
+			fetchLatestEngine("PostgreSQL"), createInstance("{{.latestEngine}}"),
 			core.ExecBeforeCmd(fmt.Sprintf("scw rdb user create instance-id={{ $.Instance.Instance.ID }} name=%s password=%s", name, password)),
 		),
 		Cmd: fmt.Sprintf("scw rdb user update instance-id={{ $.Instance.Instance.ID }} name=%s generate-password=true is-admin=true", name),
