@@ -13,8 +13,8 @@ func Test_ImageList(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands: registry.GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
-			core.ExecStoreBeforeCmd("PublicNamespace", "scw registry namespace create name=cli-public-namespace is-public=true"),
-			core.ExecStoreBeforeCmd("PrivateNamespace", "scw registry namespace create name=cli-private-namespace is-public=false"),
+			core.ExecStoreBeforeCmd("PublicNamespace", "scw registry namespace create name=cli-public-namespace-{{randint}} is-public=true"),
+			core.ExecStoreBeforeCmd("PrivateNamespace", "scw registry namespace create name=cli-private-namespace-{{randint}} is-public=false"),
 			core.BeforeFuncWhenUpdatingCassette(
 				core.ExecBeforeCmd("scw registry login"),
 			),
@@ -23,35 +23,35 @@ func Test_ImageList(t *testing.T) {
 				core.BeforeFuncCombine(
 					setupImage(
 						"busybox:1.31",
-						"rg.fr-par.scw.cloud/cli-public-namespace",
+						"{{ .PublicNamespace.Endpoint }}",
 						fmt.Sprintf("visibility_%s", registrySDK.ImageVisibilityPublic),
 						registrySDK.ImageVisibilityPublic,
 					),
 
 					setupImage(
 						"busybox:1.30",
-						"rg.fr-par.scw.cloud/cli-public-namespace",
+						"{{ .PublicNamespace.Endpoint }}",
 						fmt.Sprintf("visibility_%s", registrySDK.ImageVisibilityPrivate),
 						registrySDK.ImageVisibilityPrivate,
 					),
 
 					setupImage(
 						"busybox:1.29",
-						"rg.fr-par.scw.cloud/cli-public-namespace",
+						"{{ .PublicNamespace.Endpoint }}",
 						fmt.Sprintf("visibility_%s", registrySDK.ImageVisibilityInherit),
 						registrySDK.ImageVisibilityInherit,
 					),
 
 					setupImage(
 						"busybox:1.28",
-						"rg.fr-par.scw.cloud/cli-private-namespace",
+						"{{ .PrivateNamespace.Endpoint }}",
 						fmt.Sprintf("visibility_%s", registrySDK.ImageVisibilityPublic),
 						registrySDK.ImageVisibilityPublic,
 					),
 
 					setupImage(
 						"busybox:1.27",
-						"rg.fr-par.scw.cloud/cli-private-namespace",
+						"{{ .PrivateNamespace.Endpoint }}",
 						fmt.Sprintf("visibility_%s", registrySDK.ImageVisibilityPrivate),
 						registrySDK.ImageVisibilityPrivate,
 					),
@@ -59,7 +59,7 @@ func Test_ImageList(t *testing.T) {
 					// namespace_policy: private, image_policy:inherit
 					setupImage(
 						"busybox:1.26",
-						"rg.fr-par.scw.cloud/cli-private-namespace",
+						"{{ .PrivateNamespace.Endpoint }}",
 						fmt.Sprintf("visibility_%s", registrySDK.ImageVisibilityInherit),
 						registrySDK.ImageVisibilityInherit,
 					),
@@ -79,12 +79,16 @@ func Test_ImageList(t *testing.T) {
 }
 
 func setupImage(dockerImage string, namespaceEndpoint string, imageName string, visibility registrySDK.ImageVisibility) core.BeforeFunc {
-	remote := fmt.Sprintf("%s/%s:latest", namespaceEndpoint, imageName)
-	return core.BeforeFuncCombine(
-		core.BeforeFuncOsExec("docker", "pull", dockerImage),
-		core.BeforeFuncOsExec("docker", "tag", dockerImage, remote),
-		core.BeforeFuncOsExec("docker", "push", remote),
-		core.ExecStoreBeforeCmd("ImageListResult", "scw registry image list name="+imageName),
-		core.ExecBeforeCmd("scw registry image update {{ (index .ImageListResult 0).ID }} visibility="+visibility.String()),
-	)
+	return func(ctx *core.BeforeFuncCtx) error {
+		namespaceEndpoint := ctx.Meta.Render(namespaceEndpoint)
+		remote := fmt.Sprintf("%s/%s:latest", namespaceEndpoint, imageName)
+
+		return core.BeforeFuncCombine(
+			core.BeforeFuncOsExec("docker", "pull", dockerImage),
+			core.BeforeFuncOsExec("docker", "tag", dockerImage, remote),
+			core.BeforeFuncOsExec("docker", "push", remote),
+			core.ExecStoreBeforeCmd("ImageListResult", "scw registry image list name="+imageName),
+			core.ExecBeforeCmd("scw registry image update {{ (index .ImageListResult 0).ID }} visibility="+visibility.String()),
+		)(ctx)
+	}
 }
