@@ -1,7 +1,7 @@
 package secret
 
 import (
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	secret "github.com/scaleway/scaleway-sdk-go/api/secret/v1beta1"
 )
 
